#undef USE_PANGO
#undef USE_XFT
#undef USE_MMX
#undef OLD_PERL
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef USE_DEBUG
#undef USE_GNOME
#undef USE_ZVT
#undef USE_PLUGIN
#undef USE_XLIB
#undef USE_PANEL
#undef USE_TRANS
#undef USE_HEBREW
#undef USE_OPENSSL
#undef USE_IPV6
#undef USE_JCODE
#undef SOCKS
#undef PREFIX
#undef USING_LINUX
#undef USING_FREEBSD
#undef socklen_t
